@@ -248,6 +248,8 @@ class RequestHandler(tornado.web.RequestHandler):
 
         self.api_messages = self.application.settings.get('api_messages', {})
 
+        self.app_version = self.application.settings.get('version',None)
+
         # ez-hack-end
 
         # UIModules are available as both `modules` and `_tt_modules` in the
@@ -299,7 +301,8 @@ class RequestHandler(tornado.web.RequestHandler):
         namespace.update({
             'cdn': self.cdn,
             'hacking_ie': self.hacking_ie,
-            'debug': int(self.debug)
+            'debug': int(self.debug),
+            'app_version':self.app_version
         })
 
         return namespace
@@ -333,6 +336,12 @@ class RequestHandler(tornado.web.RequestHandler):
         pass
 
 
+    def compute_etag(self):
+
+        self.set_header('Server','Next')
+        return None
+
+
     @detect_browser
     def render(self, template_name, **kwargs):
         template_name = template_name.format(self.browser_type)
